/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "pokerui.h"

void pokerUiInit(pokergame_t *pokerGame) {
  pokerplayerui_t *playerUi;
  pokerplayer_t *playerPoker;
  vncharacter_t *character;
  uint8_t i;

  for(i = 0; i < POKER_PLAYER_COUNT; i++) {
    playerUi = pokerGame->ui.players + i;
    playerPoker = pokerGame->poker.players + i;
    character = pokerGame->scene.characters + i;

    labelInit(&playerUi->labelInfo);
    playerUi->labelInfo.fontSize = 12.0;
  }

  labelInit(&pokerGame->ui.labelGameInfo);
  pokerGame->ui.labelGameInfo.fontSize = 12.0f;
}

void pokerUiRender(pokergame_t *pokerGame) {
  pokerplayerui_t *playerUi;
  pokerplayer_t *playerPoker;
  uint8_t i;
  char buffer[256];

  sprintf(buffer, "Pot %i\n", pokerGame->poker.bet.pot);
  labelSetText(&pokerGame->ui.labelGameInfo, &pokerGame->assets.font, buffer);
  pokerGame->ui.labelGameInfo.x = 350;
  labelRender(&pokerGame->ui.labelGameInfo, &pokerGame->assets.shader);

  for(i = 0; i < POKER_PLAYER_COUNT; i++) {
    playerUi = pokerGame->ui.players + i;
    playerPoker = pokerGame->poker.players + i;

    // Player Chips
    sprintf(buffer, "Player %u - %u chips - %s%s",
      i,
      playerPoker->chips,
      i == POKER_PLAYER_HUMAN_INDEX ? "Human" : "AI",
      i == pokerGame->poker.bet.better ? " Betting" :
      playerPoker->state & POKER_PLAYER_STATE_FOLDED ? " Folded" : 
      playerPoker->state & POKER_PLAYER_STATE_OUT ? " Out" :
      ""
    );
    playerUi->labelInfo.y = (float)i * 32.0f;
    labelSetText(&playerUi->labelInfo, &pokerGame->assets.font, buffer);
    labelRender(&playerUi->labelInfo, &pokerGame->assets.shader);
  }
}

void pokerUiDispose(pokergame_t *pokerGame) {
  pokerplayerui_t *player;
  uint8_t i;

  for(i = 0; i < POKER_PLAYER_COUNT; i++) {
    player = pokerGame->ui.players + i;
    labelDispose(&player->labelInfo);
  }
}